VmdkError

Enum VmdkError 

pub enum VmdkError {
    Io(Error),
    BadMagic,
    UnsupportedVersion(u32),
    CompressedNotSupported,
    FileTooSmall,
    GeometryOverflow {
        field: &'static str,
    },
    FieldOutOfRange {
        field: &'static str,
        value: u64,
        reason: &'static str,
    },
    MalformedDescriptor(&'static str),
    UnsupportedDiskType(String),
}
Errors returned while opening or parsing a VMDK image.

Variants



Io(Error)



BadMagic



UnsupportedVersion(u32)



CompressedNotSupported



FileTooSmall



GeometryOverflow

An arithmetic computation on a geometry field overflowed u64.

Fields

field: &'static str


FieldOutOfRange

A geometry field held a value outside its valid range.

Fields

field: &'static str

The header/descriptor field that was out of range.

value: u64

The offending value as read.

reason: &'static str

Why it is invalid (the expected range).



MalformedDescriptor(&'static str)

The text descriptor was structurally malformed.



UnsupportedDiskType(String)