pub enum VmdkError {
Io(Error),
BadMagic,
UnsupportedVersion(u32),
CompressedNotSupported,
FileTooSmall,
GeometryOverflow {
field: &'static str,
},
FieldOutOfRange {
field: &'static str,
value: u64,
reason: &'static str,
},
MalformedDescriptor(&'static str),
UnsupportedDiskType(String),
}Expand description
Errors returned while opening or parsing a VMDK image.
Variants
Io(Error)
BadMagic
UnsupportedVersion(u32)
CompressedNotSupported
FileTooSmall
GeometryOverflow
An arithmetic computation on a geometry field overflowed u64.
FieldOutOfRange
A geometry field held a value outside its valid range.
Fields
MalformedDescriptor(&'static str)
The text descriptor was structurally malformed.
UnsupportedDiskType(String)